@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 ##################################################################################
 
 
+include('./include/funzioni.php');
 include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 if ($pass_admin_errata == "NO") {
@@ -30,6 +31,7 @@ $voto_tot = "";
 $voto_giornale = "";
 $punti_tot = "";
 $voti_tot = "";
+$modificatori = array();
 $num2 = 0;
 $num_giornata = substr($giornata,8);
 $num_giornata_2_cifre = $num_giornata;
@@ -50,6 +52,33 @@ next($campionato);
 } # fine for $num1
 if (!$tipo_campionato) $tipo_campionato = "N";
 
+
+if ($chiave_codifica_xor) {
+function xor_encrypt_fcb ($testo_file_voti,$chiave_codifica_xor) {
+$chiave_codifica_xor_lun = mb_strlen($chiave_codifica_xor);
+for ($num = 0 ; $num < strlen($testo_file_voti) ; $num++) {
+$rPos = $num % $chiave_codifica_xor_lun;
+$ord_key = mb_substr($chiave_codifica_xor,$rPos,1);
+#if ($num < $chiave_codifica_xor_lun) echo "$rPos - $ord_key - ".ord($ord_key)." QUI<br>";
+$ord_key = ord($ord_key);
+if ($ord_key == "195") $ord_key = "232";
+$r = ord($testo_file_voti[$num]) ^ $ord_key;
+$testo_file_voti[$num] = chr($r);
+} # fine for $num
+return $testo_file_voti;
+} # fine function xor_encrypt_fcb
+$file_voti_codificato = "$percorso_cartella_voti/voti$num_giornata_2_cifre.txt";
+$fvc = fopen($file_voti_codificato,'r');
+$testo_file_voti = fread($fvc,filesize($file_voti_codificato));
+fclose($fvc);
+$testo_file_voti = xor_encrypt_fcb($testo_file_voti,$chiave_codifica_xor);
+$fileaperto = fopen($file_voti_codificato,"w+");
+flock($fileaperto,2);
+fwrite($fileaperto,$testo_file_voti);
+flock($fileaperto,3);
+fclose($fileaperto);
+} # fine if ($chiave_codifica_xor)
+
 # prendo i voti dal file
 $voti = file("$percorso_cartella_voti/voti$num_giornata_2_cifre.txt");
 $num_voti = count($voti);
@@ -66,13 +95,14 @@ $voto_giornale[$num_calciatore] = togli_acapo($voto_giornale[$num_calciatore]) +
 } # fine for $num1
 
 
-# leggo le informazioni gi presenti in $giornata
+# leggo le informazioni gia' presenti in $giornata
 $file_giornata = file("$percorso_cartella_dati/$giornata");
 $num_linee_file_giornata = count($file_giornata);
 $num_partite = 0;
 $partite = "";
 for($num1 = 0 ; $num1 < $num_linee_file_giornata; $num1++) {
 $linea = togli_acapo($file_giornata[$num1]);
+if (substr($linea,0,12) == "#@& data #@&") $data = substr($linea,12);
 # leggo le formazioni
 if ($linea == "#@& fine formazioni #@&") $leggendo_formazioni = "NO";
 if ($leggendo_formazioni == "SI") {
@@ -97,7 +127,7 @@ $partite[$num_partite] = $linea;
 $num_partite++;
 } # fine if ($leggendo_scontri == "SI")
 if ($linea == "#@& scontri #@&") $leggendo_scontri = "SI";
-# non continuo se ci sono gi i voti
+# non continuo se ci sono gia' i voti
 if ($linea == "#@& voti #@&") $continuare = "NO";
 } # fine for $num1
 
@@ -108,6 +138,9 @@ reset($pass);
 for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
 $giocatore = key($pass);
 
+$voto_portiere = "";
+$voti_difiensori = array();
+$num_difensori = 0;
 $sostituisci_P = 0;
 $sostituisci_D = 0;
 $sostituisci_C = 0;
@@ -115,6 +148,7 @@ $sostituisci_F = 0;
 $sostituisci_A = 0;
 settype($voti_tot[$giocatore],"double");
 $voti_tot[$giocatore] = 0;
+$modificatore[$giocatore] = (double) 0;
 $schema_attuale = "00000";
 $num_sostituisci = 0;
 $formazione = "formazione_$giocatore";
@@ -135,13 +169,20 @@ $num_sostituisci++;
 } # fine if ($voto_tot[$num_calciatore] == 0 and...
 else {
 $nome_calc = $dati_calciatore[1];
-${$formazione}[$num2] = ereg_replace("$nome_calc","<b>$nome_calc</b>",${$formazione}[$num2]);
+${$formazione}[$num2] = str_replace("$nome_calc","<b>$nome_calc</b>",${$formazione}[$num2]);
 ${$formazione}[$num2] = togli_acapo(${$formazione}[$num2]);
 ${$formazione}[$num2] .= ",".$voto_tot[$num_calciatore]."
 ";
 $voti_tot[$giocatore] = $voti_tot[$giocatore] + $voto_tot[$num_calciatore];
-if ($ruolo_calc == "P") $pos_ruolo = 0;
-if ($ruolo_calc == "D") $pos_ruolo = 1;
+if ($ruolo_calc == "P") {
+$pos_ruolo = 0;
+$voto_portiere = (double) $voto_giornale[$num_calciatore];
+} # fine if ($ruolo_calc == "P")
+if ($ruolo_calc == "D") {
+$pos_ruolo = 1;
+$num_difensori++;
+$voti_difiensori[$num_difensori] = (double) $voto_giornale[$num_calciatore];
+} # fine if ($ruolo_calc == "D")
 if ($ruolo_calc == "C") $pos_ruolo = 2;
 if ($ruolo_calc == "F") $pos_ruolo = 3;
 if ($ruolo_calc == "A") $pos_ruolo = 4;
@@ -172,13 +213,20 @@ ${$formazione}[$num2] .= ",".$voto_tot[$num_calciatore]."
 ";
 if ($$nome_sostituisci >= 1 and $entrati_dalla_panchina < $max_entrate_dalla_panchina) {
 $nome_calc = $dati_calciatore[1];
-${$formazione}[$num2] = ereg_replace("$nome_calc","<b>$nome_calc</b>",${$formazione}[$num2]);
+${$formazione}[$num2] = str_replace("$nome_calc","<b>$nome_calc</b>",${$formazione}[$num2]);
 $voti_tot[$giocatore] = $voti_tot[$giocatore] + $voto_tot[$num_calciatore];
 $$nome_sostituisci = $$nome_sostituisci - 1;
 $entrati_dalla_panchina++;
 $calciatore_entrato[$num_calciatore] = "SI";
-if ($ruolo_calc == "P") $pos_ruolo = 0;
-if ($ruolo_calc == "D") $pos_ruolo = 1;
+if ($ruolo_calc == "P") {
+$pos_ruolo = 0;
+$voto_portiere = (double) $voto_giornale[$num_calciatore];
+} # fine if ($ruolo_calc == "P")
+if ($ruolo_calc == "D") {
+$pos_ruolo = 1;
+$num_difensori++;
+$voti_difiensori[$num_difensori] = (double) $voto_giornale[$num_calciatore];
+} # fine if ($ruolo_calc == "D")
 if ($ruolo_calc == "C") $pos_ruolo = 2;
 if ($ruolo_calc == "F") $pos_ruolo = 3;
 if ($ruolo_calc == "A") $pos_ruolo = 4;
@@ -204,7 +252,7 @@ $ruolo_calc = togli_acapo($ruolo_calc);
 $num_fantasisti_attuali = substr($schema_attuale,3,1);
 if (($ruolo_calc == "F" and $num_fantasisti_attuali < 1) or $ruolo_calc == "C") {
 $nome_calc = $dati_calciatore[1];
-${$formazione}[$num2] = ereg_replace("$nome_calc","<b>$nome_calc</b>",${$formazione}[$num2]);
+${$formazione}[$num2] = str_replace("$nome_calc","<b>$nome_calc</b>",${$formazione}[$num2]);
 $voti_tot[$giocatore] = $voti_tot[$giocatore] + $voto_tot[$num_calciatore];
 $sostituisci_CF = $sostituisci_CF - 1;
 $entrati_dalla_panchina++;
@@ -262,19 +310,48 @@ break;
 } # fine for $num3
 if ($schema_valido == "SI") {
 $nome_calc = $dati_calciatore[1];
-${$formazione}[$num2] = ereg_replace("$nome_calc","<b>$nome_calc</b>",${$formazione}[$num2]);
+${$formazione}[$num2] = str_replace("$nome_calc","<b>$nome_calc</b>",${$formazione}[$num2]);
 $voti_tot[$giocatore] = $voti_tot[$giocatore] + $voto_tot[$num_calciatore];
 $entrati_dalla_panchina++;
 $num_ruolo_attuale = substr($schema_attuale,$pos_ruolo,1);
 $num_ruolo_attuale++;
 $schema_attuale = substr_replace($schema_attuale,$num_ruolo_attuale,$pos_ruolo,1);
+if ($ruolo_calc == "P") $voto_portiere = (double) $voto_giornale[$num_calciatore];
+if ($ruolo_calc == "D") {
+$num_difensori++;
+$voti_difiensori[$num_difensori] = (double) $voto_giornale[$num_calciatore];
+} # fine if ($ruolo_calc == "D")
 } # fine if ($schema_valido == "SI")
 } # fine if ($voto_tot[$num_calciatore] != 0 or...
 } # fine if ($calciatore_entrato[$num_calciatore] != "SI")
 } # fine for $num2
 } # fine if ($sostituisci_per_schema == "SI")
 
-echo "$giocatore: ".$voti_tot[$giocatore]." ($schema_attuale)<br>";
+# calcolo modificatore della difesa
+if ($num_minimo_difensori_modificatore and $num_difensori >= $num_minimo_difensori_modificatore) {
+$media = (double) 0;
+$voti_media = (double) 0;
+$num_media = 0;
+if ($num_difensori_media_modificatore > $num_minimo_difensori_modificatore) $num_difensori_media_modificatore = $num_minimo_difensori_modificatore;
+rsort($voti_difiensori);
+for ($num2 = 0 ; $num2 < $num_difensori_media_modificatore ; $num2++) {
+$num_media++;
+$voti_media = $voti_media + $voti_difiensori[$num2];
+} # fine for $num2
+if ($portiere_in_media_modificatore = "SI") {
+$num_media++;
+$voti_media = $voti_media + $voto_portiere;
+} # fine if ($portiere_in_media_modificatore = "SI")
+if ($num_media) $media = $voti_media / (double) $num_media;
+if ($punti_bonus_1 and $media >= (double) $media_limite_bonus_1) $modificatore[$giocatore] = $modificatore[$giocatore] + (double) $punti_bonus_1;
+if ($punti_bonus_2 and $media >= (double) $media_limite_bonus_2) $modificatore[$giocatore] = $modificatore[$giocatore] + (double) $punti_bonus_2;
+if ($punti_bonus_3 and $media >= (double) $media_limite_bonus_3) $modificatore[$giocatore] = $modificatore[$giocatore] + (double) $punti_bonus_3;
+if ($modificatore[$giocatore]) $voti_tot[$giocatore] = $voti_tot[$giocatore] + $modificatore[$giocatore];
+} # fine if ($num_minimo_difensori_modificatore and $num_difensori >= $num_minimo_difensori_modificatore)
+
+echo "$giocatore: ".$voti_tot[$giocatore];
+if ($modificatore[$giocatore]) echo " con +".$modificatore[$giocatore];
+echo " ($schema_attuale)<br>";
 next($pass);
 } # fine for $num1
 
@@ -285,6 +362,9 @@ flock($lock,2);
 $filegiornata = fopen("$percorso_cartella_dati/$giornata","w+");
 flock($filegiornata,2);
 rewind($filegiornata);
+fwrite($filegiornata,"#@& data #@&".$data."
+#@& formazioni #@&
+");
 reset($pass);
 for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
 $giocatore = key($pass);
@@ -297,6 +377,9 @@ $num_linee_formazione = count($formazione);
 for ($num2 = 0 ; $num2 < $num_linee_formazione ; $num2++) {
 fwrite($filegiornata,$formazione[$num2]);
 } # fine for $num2
+if ($modificatore[$giocatore]) fwrite($filegiornata,"Modificatore <b>+".$modificatore[$giocatore]."</b>
+
+");
 next($pass);
 } # fine for $num1
 fwrite($filegiornata,"#@& fine formazioni #@&
@@ -351,13 +434,13 @@ $num_posizioni_pari++;
 else $fatto = "SI";
 } # fine while ($fatto != "SI")
 if ($punti_pareggio == "A") {
-$verifica_num = ereg_replace("[0-9]","",$punti_posizione[$pos_alta]);
+$verifica_num = preg_replace("/[0-9]/","",$punti_posizione[$pos_alta]);
 if ($verifica_num != "" or $punti_posizione[$pos_alta] == "") $punti_assegnati = 0;
 else $punti_assegnati = $punti_posizione[$pos_alta];
 } # fine if ($punti_pareggio == "A")
 else {
 if ($punti_pareggio == "B") {
-$verifica_num = ereg_replace("[0-9]","",$punti_posizione[$pos_bassa]);
+$verifica_num = preg_replace("/[0-9]/","",$punti_posizione[$pos_bassa]);
 if ($verifica_num != "" or $punti_posizione[$pos_bassa] == "") $punti_assegnati = 0;
 else $punti_assegnati = $punti_posizione[$pos_bassa];
 } # fine if ($punti_pareggio == "B")
@@ -365,7 +448,7 @@ else {
 # $punti_pareggio == "M"
 $punti_assegnati = 0;
 for($num2 = $pos_alta ; $num2 <= $pos_bassa; $num2++) {
-$verifica_num = ereg_replace("[0-9]","",$punti_posizione[$num2]);
+$verifica_num = preg_replace("/[0-9]/","",$punti_posizione[$num2]);
 if ($verifica_num != "" or $punti_posizione[$num2] == "") $punti_somma = 0;
 else $punti_somma = $punti_posizione[$num2];
 $punti_assegnati = $punti_assegnati + $punti_somma;
@@ -439,7 +522,7 @@ fclose($lock);
 
 } # fine if ($continuare != "NO")
 
-echo "<form method=\"post\" action=\"giornata.php\">
+echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"giornata.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
