@@ -21,6 +21,7 @@
 
 
 
+include('./include/funzioni.php');
 $parla = "NO";
 include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
@@ -89,7 +90,7 @@ $attiva_scontri_diretti = "NO";
 if ($num_giocatori == 4 or $num_giocatori == 6 or $num_giocatori == 8 or $num_giocatori == 10 or $num_giocatori == 12) {
 $attiva_scontri_diretti = "SI";
 } # fine if ($num_giocatori == 4 or...
-else echo "ERRORE: il numero di partecipanti non  di 4,6,8,10 o 12.<br><br>";
+else echo "ERRORE: il numero di partecipanti non è di 4,6,8,10 o 12.<br><br>";
 
 if ($attiva_scontri_diretti == "SI") {
 $file_scontri = file("$percorso_cartella_scontri/squadre$num_giocatori");
@@ -166,7 +167,7 @@ next($campionato);
 } # fine for $num1
 echo "</center>";
 
-echo "<center><form method=\"post\" action=\"guarda_giornata.php\">
+echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"guarda_giornata.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"hidden\" name=\"origine\" value=\"$origine\">
