@@ -4,7 +4,7 @@
 # 1) Giocatori e loro password (non utilizzare il nome admin). Inserire il nome
 # dei partecipanti tra le virgolette (senza spazi o caratteri strani). Aggiungere o 
 # togliere linee per  aggiungere o togliere giocatori. nopasswordinserita per 
-# password in bianco. GIOCATORE  diverso da giocatore (le maiuscole contano!).
+# password in bianco. GIOCATORE è diverso da giocatore (le maiuscole contano!).
 $pass["giocatore1"] = "nopasswordinserita";
 $pass["giocatore2"] = "nopasswordinserita";
 $pass["giocatore3"] = "nopasswordinserita";
@@ -18,9 +18,8 @@ $pass["giocatore8"] = "nopasswordinserita";
 $passadmin = "nopasswordinserita";
 $nome_admin_in_messaggi = "Presidente";
 
-# 3) Soldi iniziali di ogni giocatore e regole per i rilanci
+# 3) Soldi iniziali di ogni giocatore
 $soldi_iniziali = 250;
-$min_rilancio_dopo_offerta_iniziale = 2;	# quantit minima di Fanta-euro che deve rilanciare il secondo giocatore a fare una offerta
 
 # 4) Numero massimo di calciatori che si possono possedere
 $max_calciatori = 22;
@@ -37,7 +36,7 @@ $schemi = array("1433","1442","1343","1352","1532","1541","1631","13313","14312"
 
 # 7) Numero di calciatori in panchina e quanti ne possono entrare. Si possono fare 
 # sostituzioni per ruolo (il calciatore entra se un'altro del suo ruolo non ha giocato) o 
-# per schema (il calciatore entra se entrando lo schema che si forma  tra quelli 
+# per schema (il calciatore entra se entrando lo schema che si forma è tra quelli 
 # consentiti). Se sia per ruolo che per schema sono a SI si sostituisce prima per ruolo.
 $max_in_panchina = 7;
 $max_entrate_dalla_panchina = 3;
@@ -46,14 +45,14 @@ $sostituisci_fantasisti_come_centrocampisti = "NO";	# impostare a "SI" o "NO", u
 $sostituisci_per_schema = "SI";			# impostare a "SI" o "NO"
 
 # 8) Numero minimo di calciatori che devono essere titolari in formazione per ottenere 
-# punti (sono compresi anche quelli che non giocano). Non impostare a pi di 11.
+# punti (sono compresi anche quelli che non giocano). Non impostare a più di 11.
 $min_num_titolari_in_formazione = 0;
 
-# 9) Percentuale del costo pagato a cui si pu rivendere subito il calciatore
+# 9) Percentuale del costo pagato a cui si può rivendere subito il calciatore
 $percentuale_vendita = 50;
 
 # 10) Numero di calciatori inseribili in una offerta di scambio (0 per disabilitare 
-# gli scambi) e possibilit di inserire anche soldi nello scambio.
+# gli scambi) e possibilità di inserire anche soldi nello scambio.
 $num_calciatori_scambiabili = 2;
 $scambio_con_soldi = "NO";	# impostare a "SI" o "NO" (le maiuscole contano!)
 
@@ -69,23 +68,23 @@ $simbolo_centrocampista_file_calciatori = "C";
 $simbolo_fantasista_file_calciatori = "F";
 $simbolo_attaccante_file_calciatori = "A";
 $considera_fantasisti_come = "F";	# impostare a "F" per usare i fantasisti, "C" per considerarli centrocampisti, "A" attaccanti
-$num_colonna_squadra_file_calciatori = 0;	# opzionale, non c' se impostato a 0
+$num_colonna_squadra_file_calciatori = 0;	# opzionale, non c'è se impostato a 0
 
 # 12) Composizione del file con i voti di giornata (dati/votiXX.txt)
 $separatore_campi_file_voti = ",";
 $num_colonna_numcalciatore_file_voti = 1;
 $num_colonna_vototot_file_voti = 4;
 $num_colonna_votogiornale_file_voti = 4;
+$chiave_codifica_xor = ""; # Inserire la chiave se il file è codificato con xor
 
-# 13) Posizione del file dei voti da copiare (se non viene copiato a mano), pu
+# 13) Posizione del file dei voti da copiare (se non viene copiato a mano), può
 # essere anche una URL (http://...). Se il file contiene anche 01,02,... in
-# corripondeza alla giornata utilizzare anche la 2,3,4 e 5 variabile.
-$prima_parte_pos_file_voti = "";        # parte prima del n di giornata, unica nel caso non vi sia n
+# corripondeza alla giornata utilizzare anche la 2a,3a,4a e 5a variabile.
+$prima_parte_pos_file_voti = "";        # parte prima del n° di giornata, unica nel caso non vi sia n°
 $num_giornata_file_voti = "NO";         # impostare a "SI" o "NO" (le maiuscole contano!)
-$num_giornata_file_voti_doppio = "SI";  # impostare a "SI" (se il n  01,02,...) o "NO" (se il n  1,2,...)
-$seconda_parte_pos_file_voti = "";      # parte che segue il n di giornata
-$diff_num_giornata_file = 0;            # differenza tra il n della giornata del file e quello del torneo di fantacalciobazar
-$file_voti_zippato = "NO";              # impostare a "SI" se il file  compresso con zip
+$num_giornata_file_voti_doppio = "SI";  # impostare a "SI" (se il n° è 01,02,...) o "NO" (se il n° è 1,2,...)
+$seconda_parte_pos_file_voti = "";      # parte che segue il n° di giornata
+$diff_num_giornata_file = 0;            # differenza tra il n° della giornata del file e quello del torneo di fantacalciobazar
                                      
 # 14) Dove e se far vedere i risultati di giornata
 $mostra_giornate_in_login = "SI";	# impostare a "SI" o "NO"
@@ -94,12 +93,12 @@ $mostra_giornate_in_mercato = "SI";	# impostare a "SI" o "NO"
 # 15) Lista dei campionati che verranno disputati. Tra le virgolette vi devono 
 # essere la giornata iniziale e quella finale separate da un -. Non sovrapporre 2 
 # campionati. Si possono aggiungere o togliere linee.
-$campionato["1-8"] = "S";		# impostare a "S" per scontri diretti, "P" per punti, "V" per somma voti o "N" per nessuno
-$campionato["9-16"] = "S";
-$campionato["17-32"] = "N";
-$campionato["33-38"] = "V";
+$campionato["1-28"] = "S";		# impostare a "S" per scontri diretti, "P" per punti, "V" per somma voti o "N" per nessuno
+$campionato["29-31"] = "P";
+$campionato["32-32"] = "N";
+$campionato["33-34"] = "V";
 
-# 16) Dati per i campionati a scontri diretti. Servono solo se si  impostato
+# 16) Dati per i campionati a scontri diretti. Servono solo se si è impostato
 # un campionato a "S".
 $soglia_voti_primo_gol = 66;
 $incremento_voti_gol_successivi = 4;
@@ -108,10 +107,10 @@ $punti_partita_vinta = 3;
 $punti_partita_pareggiata = 1;
 $punti_partita_persa = 0;
 
-# 17) Dati per i campionati a punti per posizione di giornata. Servono solo se si 
+# 17) Dati per i campionati a punti per posizione di giornata. Servono solo se si è
 # impostato un campionato a "P". Togliere o aggiungere linee a seconda del numero di
 # giocatori
-$punti_pareggio = "M";		# impostare a "M" per la media, "A" per i punti della posizione pi alta o "B" per quelli della pi bassa
+$punti_pareggio = "M";		# impostare a "M" per la media, "A" per i punti della posizione più alta o "B" per quelli della più bassa
 $punti_posizione[1] = 10;	# punti assegnati al primo di giornata
 $punti_posizione[2] = 8;
 $punti_posizione[3] = 6;
@@ -121,16 +120,27 @@ $punti_posizione[6] = 2;
 $punti_posizione[7] = 1;
 $punti_posizione[8] = 0;
 
+# 18) Modificatore della difesa
+$num_minimo_difensori_modificatore = 4; # Numero minimo di difensori per attivare il modificatore. Impostare a 0 per disattivare il modificatore
+$num_difensori_media_modificatore = 3; # numero dei difensori con voti migliori che fanno media
+$portiere_in_media_modificatore = "SI"; # se il portire deve essere considerato nella media
+$media_limite_bonus_1 = 6; # la media che attiva il primo bonus 
+$punti_bonus_1 = 1; # punti che assegna il primo bonus
+$media_limite_bonus_2 = 6.5;
+$punti_bonus_2 = 2;
+$media_limite_bonus_3 = 7;
+$punti_bonus_3 = 3;
 
-# 18) Lo stato del mercato pu essere "A" per aperto (tutte le operazioni consentite),
+
+# 19) Lo stato del mercato può essere "A" per aperto (tutte le operazioni consentite),
 # "S" per sospeso (consentiti solo rilanci e vendita immediata di calciatori) o "C"
 # per chiuso (nessuna operazione di mercato consentita)
 $stato_mercato = "A";
 
-# 19) Impostare a "NO" se si vuole che i giocatori non possano pi cambiare il nome
+# 20) Impostare a "NO" se si vuole che i giocatori non possano più cambiare il nome
 # e l'indirizzo del sito della loro squadra
 $nome_squadra_cambiabile = "SI";		# impostare a "SI" o "NO"
 $indirizzo_sito_squadra_cambiabile = "SI"	# impostare a "SI" o "NO"
 
 
-?>
+?>
\ No newline at end of file
