@@ -19,6 +19,7 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ##################################################################################
 
+include('./include/funzioni.php');
 include("./controlla_pass.php");
 if ($pass_errata != "SI") {
 
@@ -84,12 +85,12 @@ if ($nuovo_costo) { $costo_mostra = $nuovo_costo; }
 else { $costo_mostra = $costo; }
 if ($costo_mostra >= $valore_offerta) {
 $inserire = "NO";
-$frase .= "L'offerta non  abbastanza alta per comprare il calciatore.<br>";
+$frase .= "L'offerta non è abbastanza alta per comprare il calciatore.<br>";
 } # fine if ($costo >= $valore_offerta)
 else {
 if ($prima_offerta == "SI" and ($costo_mostra + $min_rilancio_dopo_offerta_iniziale - 1) >= $valore_offerta) {
 $inserire = "NO";
-$frase .= "L'offerta non  abbastanza alta per comprare il calciatore (in quanto seconda offerta si devono offrire almeno ".($costo_mostra + $min_rilancio_dopo_offerta_iniziale)." fanta-euro).<br>";
+$frase .= "L'offerta non è abbastanza alta per comprare il calciatore (in quanto seconda offerta si devono offrire almeno ".($costo_mostra + $min_rilancio_dopo_offerta_iniziale)." fanta-euro).<br>";
 } # fine if ($prima_offerta == "SI" and ($costo_mostra + $min_rilancio_dopo_offerta_iniziale - 1) >= $valore_offerta)
 } # fine else if ($costo >= $valore_offerta)
 } # fine if ($num_calciatore == $numero)
@@ -108,7 +109,7 @@ if ($num_calciatore == $numero) {
 $trovato = "SI";
 $nome = $dati_calciatore[($num_colonna_nome_file_calciatori-1)];
 $nome = togli_acapo($nome);
-$nome = ereg_replace("\"","",$nome);
+$nome = str_replace("\"","",$nome);
 $s_ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
 $s_ruolo = togli_acapo($s_ruolo);
 $ruolo = $s_ruolo;
@@ -134,15 +135,15 @@ $frase .= "Calciatore inesistente.<br>";
 
 if ($nuova_offerta == "SI" and $stato_mercato == "S") {
 $inserire = "NO";
-echo "<center>Il mercato  <b>sospeso</b> in questo momento.</center><br>";
+echo "<center>Il mercato è <b>sospeso</b> in questo momento.</center><br>";
 } # fine if ($nuova_offerta == "SI" and $stato_mercato == "S")
 
 if ($stato_mercato == "C") {
 $inserire = "NO";
-echo "<center>Il mercato  <b>chiuso</b> in questo momento.</center><br>";
+echo "<center>Il mercato è <b>chiuso</b> in questo momento.</center><br>";
 } # fine if ($stato_mercato == "C")
 
-$verifica_num = ereg_replace("[0-9]","",$valore_offerta);
+$verifica_num = preg_replace("/[0-9]/","",$valore_offerta);
 if ($verifica_num != "" or $valore_offerta == "" or $valore_offerta == 0) {
 $inserire = "NO";
 $frase .= "L'offerta deve essere un numero intero positivo.<br>";
@@ -251,24 +252,26 @@ fwrite($file_mercato,$calciatori[$num_linea]);
 flock($file_mercato,3);
 fclose($file_mercato);
 echo "<html>
-<header>
+<head>
+<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" >
 <title> fantacalcio </title>
 <meta http-equiv=\"refresh\" content=\"1; url=mercato.php?nome_utente=$nome_utente&pass_fornita=$pass_fornita\">
-</header>
+</head>
 <body bgcolor=#ffffff>
 Offerta inserita!";
 } # fine if ($inserire == "SI");
 
 else {
 echo "<html>
-<header>
+<head>
+<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" >
 <title> Fantacalcio </title>
-</header>
+</head>
 <body bgcolor=#ffffff>";
 echo $frase;
 } # fine else if ($inserire == "SI");
 
-echo "<center><form method=\"post\" action=\"mercato.php\">
+echo "<center><form  accept-charset=\"utf-8\"  accept-charset=\"utf-8\"  method=\"post\" action=\"mercato.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
