@@ -20,6 +20,7 @@
 ##################################################################################
 
 
+include('./include/funzioni.php');
 include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 if ($pass_errata != "SI" or $pass_admin_errata == "NO") {
@@ -70,7 +71,7 @@ echo "</center>";
 if ($ricarica) $testo_vecchio = $nuovo_messaggio;
 
 echo "<table><tr>
-<form method=\"post\" action=\"messaggi.php\">
+<form  accept-charset=\"utf-8\" method=\"post\" action=\"messaggi.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <td><textarea name=\"nuovo_messaggio\" rows=4 cols=50 wrap=\"virtual\">$testo_vecchio</textarea></td>
@@ -93,7 +94,7 @@ if ($voto_palese == "SI") echo "palese</b></center></font><br>";
 else echo "anonim$o</b></center></font><br>";
 if ($voti_consentiti > 1) echo "<center><font size=-2>$voti_consentiti voti consentiti</font></center><br>";
 echo "<font size=-2><font color=\"red\">$domanda</font><br>
-<form method=\"post\" action=\"./vota_sondaggio.php\">";
+<form  accept-charset=\"utf-8\" method=\"post\" action=\"./vota_sondaggio.php\">";
 $num_opzioni = count($opzioni);
 for ($num1 = 0 ; $num1 < $num_opzioni; $num1++) {
 $opzione = $num1+1;
@@ -109,7 +110,7 @@ echo "<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 
 echo "</td></tr></table>";
 
-echo "<center><form method=\"post\" action=\"mercato.php\">
+echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"mercato.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_utente\">
