@@ -20,6 +20,7 @@
 ##################################################################################
 
 
+include('./include/funzioni.php');
 include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 if ($pass_errata != "SI") {
@@ -93,7 +94,7 @@ if ($vecchio_proprietario) { $proprietario_mostra = "$proprietario <font size=-2
 else { $proprietario_mostra = $proprietario; }
 if ($nuovo_costo) { $costo_mostra = $nuovo_costo; }
 else { $costo_mostra = $costo; }
-if ($prima_offerta == "SI" and $min_rilancio_dopo_offerta_iniziale != 1) $proprietario_mostra .= "&nbsp;<font size=\"-2\">(1)</font>";
+if ($prima_offerta == "SI" and $min_rilancio_dopo_offerta_iniziale != 1) $proprietario_mostra .= "&nbsp;<font size=\"-2\">(1°)</font>";
 echo"<tr><td>$numero</td>
 <td>$nome</td>
 <td>$ruolo</td>
@@ -115,7 +116,7 @@ if ($num_calciatore == $numero) {
 $trovato = "SI";
 $nome = $dati_calciatore[($num_colonna_nome_file_calciatori-1)];
 $nome = togli_acapo($nome);
-$nome = ereg_replace("\"","",$nome);
+$nome = str_replace("\"","",$nome);
 $s_ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
 $s_ruolo = togli_acapo($s_ruolo);
 $ruolo = $s_ruolo;
@@ -143,12 +144,12 @@ echo "</table>";
 
 if ($nuova_offerta == "SI" and $stato_mercato == "S") {
 $offribile = "NO";
-echo "<center>Il mercato  <b>sospeso</b> in questo momento.</center><br>";
+echo "<center>Il mercato è <b>sospeso</b> in questo momento.</center><br>";
 } # fine if ($nuova_offerta == "SI" and $stato_mercato == "S")
 
 if ($stato_mercato == "C") {
 $offribile = "NO";
-echo "<center>Il mercato  <b>chiuso</b> in questo momento.</center><br>";
+echo "<center>Il mercato è <b>chiuso</b> in questo momento.</center><br>";
 } # fine if ($stato_mercato == "C")
 
 $num_calciatori_comprabili = $max_calciatori - $num_calciatori_posseduti;
@@ -164,7 +165,7 @@ echo "<br>Soldi ancora da spendere: <b>$soldi_spendibili</b> Fanta-Euro$frase_to
 Numero di calciatori ancora comperabili: <b>$num_calciatori_comprabili</b>.<br>";
 
 if ($offribile == "SI") {
-echo "<br><form method=\"post\" action=\"inserisci_offerta.php\">
+echo "<br><form  accept-charset=\"utf-8\" method=\"post\" action=\"inserisci_offerta.php\">
 Fai una offerta per <b>$nome</b> di
 <input type=\"text\" name=\"valore_offerta\" size=\"8\">
 Fanta-Euro.
@@ -177,7 +178,7 @@ Fanta-Euro.
 
 else { echo "<br><br>Non si possono fare offerte per questo giocatore!<br>"; }
 
-echo "<center><form method=\"post\" action=\"mercato.php\">
+echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"mercato.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
