@@ -20,6 +20,7 @@
 ##################################################################################
 
 
+include('./include/funzioni.php');
 include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 if ($pass_errata != "SI") {
@@ -104,11 +105,11 @@ $lista_calciatori = "";
 $soldi_spesi = 0;
 $num_calciatori_posseduti = 0;
 $linea_offerto = "";
-$linea_comprato_P = "";
-$linea_comprato_D = "";
-$linea_comprato_C = "";
-$linea_comprato_F = "";
-$linea_comprato_A = "";
+$linea_comprato_P = array();
+$linea_comprato_D = array();
+$linea_comprato_C = array();
+$linea_comprato_F = array();
+$linea_comprato_A = array();
 $tab_comprati = "";
 $tab_offerte = "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
 <tr><td>Num.</td>
@@ -180,7 +181,7 @@ $tab_offerte .= "<tr><td>$numero</td>
 } # fine if ($proprietario == $giocatore)
 } # fine for $num2
 
-if ($giocatore == $nome_utente) { echo "<form method=\"post\" action=\"seleziona_squadra.php\">"; }
+if ($giocatore == $nome_utente) { echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"seleziona_squadra.php\">"; }
 echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
 <tr><td><font size=-2>Pos.</font></td>
 <td><font size=-2>Num.</font></td>
@@ -203,41 +204,41 @@ $tab_titolari_D = "";
 $tab_titolari_C = "";
 $tab_titolari_F = "";
 $tab_titolari_A = "";
-$inserito = "";
+$inserito = array();
 $num_pos = 1;
 for ($num2 = 0 ; $num2 < $num_titolari ; $num2++) {
 $numero_titolare = $titolari[$num2];
 if ($linea_comprato_P[$numero_titolare]) {
-$linea_comprato_P[$numero_titolare] = ereg_replace("value=\"titolare\"","value=\"titolare\" checked",$linea_comprato_P[$numero_titolare]);
-$linea_comprato_P[$numero_titolare] = ereg_replace("<tr><td>&nbsp;</td>","<tr><td>$num_pos</td>",$linea_comprato_P[$numero_titolare]);
+$linea_comprato_P[$numero_titolare] = preg_replace("/value=\"titolare\"/","value=\"titolare\" checked",$linea_comprato_P[$numero_titolare]);
+$linea_comprato_P[$numero_titolare] = preg_replace("|<tr><td>&nbsp;<\/td>|","<tr><td>$num_pos</td>",$linea_comprato_P[$numero_titolare]);
 $num_pos++;
 $tab_titolari_P .= $linea_comprato_P[$numero_titolare];
 $inserito[$numero_titolare] = "SI";
 } # fine if ($linea_comprato_P[$numero_titolare])
 if ($linea_comprato_D[$numero_titolare]) {
-$linea_comprato_D[$numero_titolare] = ereg_replace("value=\"titolare\"","value=\"titolare\" checked",$linea_comprato_D[$numero_titolare]);
-$linea_comprato_D[$numero_titolare] = ereg_replace("<tr><td>&nbsp;</td>","<tr><td>$num_pos</td>",$linea_comprato_D[$numero_titolare]);
+$linea_comprato_D[$numero_titolare] = preg_replace("/value=\"titolare\"/","value=\"titolare\" checked",$linea_comprato_D[$numero_titolare]);
+$linea_comprato_D[$numero_titolare] = preg_replace("|<tr><td>&nbsp;</td>|","<tr><td>$num_pos</td>",$linea_comprato_D[$numero_titolare]);
 $num_pos++;
 $tab_titolari_D .= $linea_comprato_D[$numero_titolare];
 $inserito[$numero_titolare] = "SI";
 } # fine if ($linea_comprato_D[$numero_titolare])
 if ($linea_comprato_C[$numero_titolare]) {
-$linea_comprato_C[$numero_titolare] = ereg_replace("value=\"titolare\"","value=\"titolare\" checked",$linea_comprato_C[$numero_titolare]);
-$linea_comprato_C[$numero_titolare] = ereg_replace("<tr><td>&nbsp;</td>","<tr><td>$num_pos</td>",$linea_comprato_C[$numero_titolare]);
+$linea_comprato_C[$numero_titolare] = preg_replace("/value=\"titolare\"/","value=\"titolare\" checked",$linea_comprato_C[$numero_titolare]);
+$linea_comprato_C[$numero_titolare] = preg_replace("|<tr><td>&nbsp;</td>|","<tr><td>$num_pos</td>",$linea_comprato_C[$numero_titolare]);
 $num_pos++;
 $tab_titolari_C .= $linea_comprato_C[$numero_titolare];
 $inserito[$numero_titolare] = "SI";
 } # fine if ($linea_comprato_C[$numero_titolare])
 if ($linea_comprato_F[$numero_titolare]) {
-$linea_comprato_F[$numero_titolare] = ereg_replace("value=\"titolare\"","value=\"titolare\" checked",$linea_comprato_F[$numero_titolare]);
-$linea_comprato_F[$numero_titolare] = ereg_replace("<tr><td>&nbsp;</td>","<tr><td>$num_pos</td>",$linea_comprato_F[$numero_titolare]);
+$linea_comprato_F[$numero_titolare] = preg_replace("/value=\"titolare\"/","value=\"titolare\" checked",$linea_comprato_F[$numero_titolare]);
+$linea_comprato_F[$numero_titolare] = preg_replace("|<tr><td>&nbsp;</td>|","<tr><td>$num_pos</td>",$linea_comprato_F[$numero_titolare]);
 $num_pos++;
 $tab_titolari_F .= $linea_comprato_F[$numero_titolare];
 $inserito[$numero_titolare] = "SI";
 } # fine if ($linea_comprato_F[$numero_titolare])
 if ($linea_comprato_A[$numero_titolare]) {
-$linea_comprato_A[$numero_titolare] = ereg_replace("value=\"titolare\"","value=\"titolare\" checked",$linea_comprato_A[$numero_titolare]);
-$linea_comprato_A[$numero_titolare] = ereg_replace("<tr><td>&nbsp;</td>","<tr><td>$num_pos</td>",$linea_comprato_A[$numero_titolare]);
+$linea_comprato_A[$numero_titolare] = preg_replace("/value=\"titolare\"/","value=\"titolare\" checked",$linea_comprato_A[$numero_titolare]);
+$linea_comprato_A[$numero_titolare] = preg_replace("|<tr><td>&nbsp;</td>|","<tr><td>$num_pos</td>",$linea_comprato_A[$numero_titolare]);
 $num_pos++;
 $tab_titolari_A .= $linea_comprato_A[$numero_titolare];
 $inserito[$numero_titolare] = "SI";
@@ -259,41 +260,41 @@ for ($num2 = 0 ; $num2 < $num_panchinari ; $num2++) {
 $numero_panchinaro = $panchinari[$num2];
 $num_in_panchina = $num2 + 1;
 if ($linea_comprato_P[$numero_panchinaro]) {
-$linea_comprato_P[$numero_panchinaro] = ereg_replace("value=\"panchinaro\"","value=\"panchinaro\" checked",$linea_comprato_P[$numero_panchinaro]);
-$linea_comprato_P[$numero_panchinaro] = ereg_replace("option value=\"$num_in_panchina\"","option value=\"$num_in_panchina\" selected",$linea_comprato_P[$numero_panchinaro]);
-$linea_comprato_P[$numero_panchinaro] = ereg_replace("<tr><td>&nbsp;</td>","<tr><td>$num_pos</td>",$linea_comprato_P[$numero_panchinaro]);
+$linea_comprato_P[$numero_panchinaro] = preg_replace("/value=\"panchinaro\"/","value=\"panchinaro\" checked",$linea_comprato_P[$numero_panchinaro]);
+$linea_comprato_P[$numero_panchinaro] = preg_replace("/option value=\"$num_in_panchina\"/","option value=\"$num_in_panchina\" selected",$linea_comprato_P[$numero_panchinaro]);
+$linea_comprato_P[$numero_panchinaro] = preg_replace("|<tr><td>&nbsp;</td>|","<tr><td>$num_pos</td>",$linea_comprato_P[$numero_panchinaro]);
 $num_pos++;
 $tab_panchinari .= $linea_comprato_P[$numero_panchinaro];
 $inserito[$numero_panchinaro] = "SI";
 } # fine if ($linea_comprato_P[$numero_panchinaro])
 if ($linea_comprato_D[$numero_panchinaro]) {
-$linea_comprato_D[$numero_panchinaro] = ereg_replace("value=\"panchinaro\"","value=\"panchinaro\" checked",$linea_comprato_D[$numero_panchinaro]);
-$linea_comprato_D[$numero_panchinaro] = ereg_replace("option value=\"$num_in_panchina\"","option value=\"$num_in_panchina\" selected",$linea_comprato_D[$numero_panchinaro]);
-$linea_comprato_D[$numero_panchinaro] = ereg_replace("<tr><td>&nbsp;</td>","<tr><td>$num_pos</td>",$linea_comprato_D[$numero_panchinaro]);
+$linea_comprato_D[$numero_panchinaro] = preg_replace("/value=\"panchinaro\"/","value=\"panchinaro\" checked",$linea_comprato_D[$numero_panchinaro]);
+$linea_comprato_D[$numero_panchinaro] = preg_replace("/option value=\"$num_in_panchina\"/","option value=\"$num_in_panchina\" selected",$linea_comprato_D[$numero_panchinaro]);
+$linea_comprato_D[$numero_panchinaro] = preg_replace("|<tr><td>&nbsp;</td>|","<tr><td>$num_pos</td>",$linea_comprato_D[$numero_panchinaro]);
 $num_pos++;
 $tab_panchinari .= $linea_comprato_D[$numero_panchinaro];
 $inserito[$numero_panchinaro] = "SI";
 } # fine if ($linea_comprato_D[$numero_panchinaro])
 if ($linea_comprato_C[$numero_panchinaro]) {
-$linea_comprato_C[$numero_panchinaro] = ereg_replace("value=\"panchinaro\"","value=\"panchinaro\" checked",$linea_comprato_C[$numero_panchinaro]);
-$linea_comprato_C[$numero_panchinaro] = ereg_replace("option value=\"$num_in_panchina\"","option value=\"$num_in_panchina\" selected",$linea_comprato_C[$numero_panchinaro]);
-$linea_comprato_C[$numero_panchinaro] = ereg_replace("<tr><td>&nbsp;</td>","<tr><td>$num_pos</td>",$linea_comprato_C[$numero_panchinaro]);
+$linea_comprato_C[$numero_panchinaro] = preg_replace("/value=\"panchinaro\"/","value=\"panchinaro\" checked",$linea_comprato_C[$numero_panchinaro]);
+$linea_comprato_C[$numero_panchinaro] = preg_replace("/option value=\"$num_in_panchina\"/","option value=\"$num_in_panchina\" selected",$linea_comprato_C[$numero_panchinaro]);
+$linea_comprato_C[$numero_panchinaro] = preg_replace("|<tr><td>&nbsp;</td>|","<tr><td>$num_pos</td>",$linea_comprato_C[$numero_panchinaro]);
 $num_pos++;
 $tab_panchinari .= $linea_comprato_C[$numero_panchinaro];
 $inserito[$numero_panchinaro] = "SI";
 } # fine if ($linea_comprato_C[$numero_panchinaro])
 if ($linea_comprato_F[$numero_panchinaro]) {
-$linea_comprato_F[$numero_panchinaro] = ereg_replace("value=\"panchinaro\"","value=\"panchinaro\" checked",$linea_comprato_F[$numero_panchinaro]);
-$linea_comprato_F[$numero_panchinaro] = ereg_replace("option value=\"$num_in_panchina\"","option value=\"$num_in_panchina\" selected",$linea_comprato_F[$numero_panchinaro]);
-$linea_comprato_F[$numero_panchinaro] = ereg_replace("<tr><td>&nbsp;</td>","<tr><td>$num_pos</td>",$linea_comprato_F[$numero_panchinaro]);
+$linea_comprato_F[$numero_panchinaro] = preg_replace("/value=\"panchinaro\"/","value=\"panchinaro\" checked",$linea_comprato_F[$numero_panchinaro]);
+$linea_comprato_F[$numero_panchinaro] = preg_replace("/option value=\"$num_in_panchina\"/","option value=\"$num_in_panchina\" selected",$linea_comprato_F[$numero_panchinaro]);
+$linea_comprato_F[$numero_panchinaro] = preg_replace("|<tr><td>&nbsp;</td>|","<tr><td>$num_pos</td>",$linea_comprato_F[$numero_panchinaro]);
 $num_pos++;
 $tab_panchinari .= $linea_comprato_F[$numero_panchinaro];
 $inserito[$numero_panchinaro] = "SI";
 } # fine if ($linea_comprato_F[$numero_panchinaro])
 if ($linea_comprato_A[$numero_panchinaro]) {
-$linea_comprato_A[$numero_panchinaro] = ereg_replace("value=\"panchinaro\"","value=\"panchinaro\" checked",$linea_comprato_A[$numero_panchinaro]);
-$linea_comprato_A[$numero_panchinaro] = ereg_replace("option value=\"$num_in_panchina\"","option value=\"$num_in_panchina\" selected",$linea_comprato_A[$numero_panchinaro]);
-$linea_comprato_A[$numero_panchinaro] = ereg_replace("<tr><td>&nbsp;</td>","<tr><td>$num_pos</td>",$linea_comprato_A[$numero_panchinaro]);
+$linea_comprato_A[$numero_panchinaro] = preg_replace("/value=\"panchinaro\"/","value=\"panchinaro\" checked",$linea_comprato_A[$numero_panchinaro]);
+$linea_comprato_A[$numero_panchinaro] = preg_replace("/option value=\"$num_in_panchina\"/","option value=\"$num_in_panchina\" selected",$linea_comprato_A[$numero_panchinaro]);
+$linea_comprato_A[$numero_panchinaro] = preg_replace("|<tr><td>&nbsp;</td>|","<tr><td>$num_pos</td>",$linea_comprato_A[$numero_panchinaro]);
 $num_pos++;
 $tab_panchinari .= $linea_comprato_A[$numero_panchinaro];
 $inserito[$numero_panchinaro] = "SI";
@@ -314,27 +315,27 @@ for ($num2 = 0 ; $num2 < $num_calciatori ; $num2++) {
 $numero_fuori = $lista_calciatori[$num2];
 if ($inserito[$numero_fuori] != "SI") {
 if ($linea_comprato_P[$numero_fuori]) {
-$linea_comprato_P[$numero_fuori] = ereg_replace("value=\"fuori\"","value=\"fuori\" checked",$linea_comprato_P[$numero_fuori]);
+$linea_comprato_P[$numero_fuori] = str_replace("value=\"fuori\"","value=\"fuori\" checked",$linea_comprato_P[$numero_fuori]);
 $tab_fuori_P .= $linea_comprato_P[$numero_fuori];
 $inserito[$numero_fuori] = "SI";
 } # fine if ($linea_comprato_P[$numero_fuori])
 if ($linea_comprato_D[$numero_fuori]) {
-$linea_comprato_D[$numero_fuori] = ereg_replace("value=\"fuori\"","value=\"fuori\" checked",$linea_comprato_D[$numero_fuori]);
+$linea_comprato_D[$numero_fuori] = str_replace("value=\"fuori\"","value=\"fuori\" checked",$linea_comprato_D[$numero_fuori]);
 $tab_fuori_D .= $linea_comprato_D[$numero_fuori];
 $inserito[$numero_fuori] = "SI";
 } # fine if ($linea_comprato_D[$numero_fuori])
 if ($linea_comprato_C[$numero_fuori]) {
-$linea_comprato_C[$numero_fuori] = ereg_replace("value=\"fuori\"","value=\"fuori\" checked",$linea_comprato_C[$numero_fuori]);
+$linea_comprato_C[$numero_fuori] = str_replace("value=\"fuori\"","value=\"fuori\" checked",$linea_comprato_C[$numero_fuori]);
 $tab_fuori_C .= $linea_comprato_C[$numero_fuori];
 $inserito[$numero_fuori] = "SI";
 } # fine if ($linea_comprato_C[$numero_fuori])
 if ($linea_comprato_F[$numero_fuori]) {
-$linea_comprato_F[$numero_fuori] = ereg_replace("value=\"fuori\"","value=\"fuori\" checked",$linea_comprato_F[$numero_fuori]);
+$linea_comprato_F[$numero_fuori] = str_replace("value=\"fuori\"","value=\"fuori\" checked",$linea_comprato_F[$numero_fuori]);
 $tab_fuori_F .= $linea_comprato_F[$numero_fuori];
 $inserito[$numero_fuori] = "SI";
 } # fine if ($linea_comprato_F[$numero_fuori])
 if ($linea_comprato_A[$numero_fuori]) {
-$linea_comprato_A[$numero_fuori] = ereg_replace("value=\"fuori\"","value=\"fuori\" checked",$linea_comprato_A[$numero_fuori]);
+$linea_comprato_A[$numero_fuori] = str_replace("value=\"fuori\"","value=\"fuori\" checked",$linea_comprato_A[$numero_fuori]);
 $tab_fuori_A .= $linea_comprato_A[$numero_fuori];
 $inserito[$numero_fuori] = "SI";
 } # fine if ($linea_comprato_A[$numero_fuori])
@@ -364,7 +365,7 @@ echo "<center><br>
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 </center></form>";
 if ($nome_squadra_cambiabile == "SI") {
-echo "<form method=\"post\" action=\"squadra.php\">
+echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"squadra.php\">
 <input type=\"submit\" name=\"cambia_soprannome\" value=\"Cambia il nome\">
  della squadra in <input type=\"text\" name=\"nuovo_soprannome\" size=\"20\" maxlength=\"20\" value=\"$soprannome_squadra\">
 <input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_squadra\">
@@ -373,7 +374,7 @@ echo "<form method=\"post\" action=\"squadra.php\">
 </form>";
 } # fine if ($nome_squadra_cambiabile == "SI")
 if ($indirizzo_sito_squadra_cambiabile == "SI") {
-echo "<form method=\"post\" action=\"squadra.php\">
+echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"squadra.php\">
 <input type=\"submit\" name=\"cambia_homepage\" value=\"Cambia l'indirizzo\">
  della pagina ufficiale in <input type=\"text\" name=\"nuova_home_page\" size=\"20\" maxlength=\"50\" value=\"$home_page_squadra_vedi\">
 <input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_squadra\">
@@ -408,7 +409,7 @@ echo "<hr width=\"95%\">";
 next($pass);
 } # fine for $num1
 
-echo "<center><form method=\"post\" action=\"mercato.php\">
+echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"mercato.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_utente\">
