@@ -20,6 +20,7 @@
 ##################################################################################
 
 
+include('./include/funzioni.php');
 include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 if ($pass_errata != "SI") {
@@ -31,7 +32,12 @@ if ($sfondo_tab == "") $sfondo_tab = "#b9ccd4";
 $calciatori = file("$percorso_cartella_voti/calciatori.txt");
 $num_calciatori = count($calciatori);
 
-echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
+if ($formato_pda == "SI") echo "<table width=3 border=1 cellspacing=0 cellpadding=1 align=\"center\" bgcolor=\"$sfondo_tab\">
+<tr><td>Num.</td>
+<td>__________Nome__________</td>
+<td><font size=-2>Ruolo</font></td>
+<td>&nbsp;</td></tr>";
+else echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
 <tr><td>Num.</td>
 <td>_____________Nome_____________</td>
 <td><font size=-2>Ruolo</font></td>
@@ -44,7 +50,7 @@ $numero = $dati_calciatore[($num_colonna_numcalciatore_file_calciatori-1)];
 $numero = togli_acapo($numero);
 $nome = $dati_calciatore[($num_colonna_nome_file_calciatori-1)];
 $nome = togli_acapo($nome);
-$nome = ereg_replace("\"","",$nome);
+$nome = preg_replace("/\"/","",$nome);
 $s_ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
 $s_ruolo = togli_acapo($s_ruolo);
 $ruolo = $s_ruolo;
@@ -56,17 +62,27 @@ if ($s_ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
 if ($s_ruolo == $simbolo_attaccante_file_calciatori) $ruolo = "A";
 
 if ($ruolo == $ruolo_guarda or $ruolo_guarda == "tutti") {
-echo"<tr><td align=\"center\"><a href=\"stat_calciatore.php?num_calciatore=$numero&ruolo_guarda=$ruolo_guarda&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">$numero</a></td>
+echo"<tr><td align=\"center\"><a href=\"stat_calciatore.php?num_calciatore=$numero&amp;ruolo_guarda=$ruolo_guarda&amp;nome_utente=$nome_utente&amp;pass_fornita=$pass_fornita\">$numero</a></td>
 <td>$nome</td>
 <td>$ruolo</td>
-<td><a href=\"offerta.php?num_calciatore=$numero&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">offri</a></td>
+<td>";
+if ($formato_pda == "SI") {
+echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"offerta.php\">
+<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
+<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
+<input type=\"hidden\" name=\"num_calciatore\" value=\"$numero\">
+<input type=\"submit\" value=\"offri\">
+</form>";
+} # fine if ($formato_pda == "SI")
+else echo "<a href=\"offerta.php?num_calciatore=$numero&amp;nome_utente=$nome_utente&amp;pass_fornita=$pass_fornita\">offri</a>";
+echo "</td>
 </tr>";
 } # fine if ($ruolo == $ruolo_guarda or ...)
 
 } # fine for $num1
 echo "</table>";
 
-echo "<center><form method=\"post\" action=\"mercato.php\">
+echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"mercato.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
